Learn R Programming

pvLRT (version 0.5.1)

as.matrix.pvlrt: Casting a pvlrt object as a matrix of log LR statistics

Description

Casting a pvlrt object as a matrix of log LR statistics

Usage

# S3 method for pvlrt
as.matrix(x, ...)

Value

Returns a matrix with the same dimensions as the input contingency table in the original pvlrt call, with each cell providing the corresponding value of the observed log-likelihood ratio test statistic.

Arguments

x

a pvlrt object; an output of function pvlrt().

...

other input parameters. Currently unused.

See Also

pvlrt

Examples

Run this code

# 500 bootstrap iterations (nsim) in the example below
# are for quick demonstration only --
# we recommended setting nsim to 10000 (default) or bigger

test1 <- pvlrt(statin46, nsim = 500)
as.matrix(test1)

Run the code above in your browser using DataLab