Learn R Programming

pvLRT (version 0.5.1)

faers22q3raw: FDA FAERS dataset for 2022 Q3

Description

The raw FDA FAERS dataset for 2022 Q3; downloaded from FDA's website and then subsetted to inlcude incidences with ROLE_COD == "PS".

Usage

faers22q3raw

Arguments

Format

An object of class data.table (inherits from data.frame) with 496312 rows and 3 columns.

Details

obtained from the FDA FAERS database for the quarters 2014Q3 - 2020Q4

This is a raw incidence data stored as a data.table with each row corresponding to a specific incidence index by case ids. It contains the following columns:

  • CASEID - case ids for each incidence

  • DRUG - names of the drugs

  • AE - names of the adverse events