Learn R Programming

pvLRT (version 0.5.1)

lrt_zi_poisson: Pseudo Likelihood Ratio Test under the zero-inflated Poisson model with relative reporting rate parametrization

Description

Pseudo Likelihood Ratio Test under the zero-inflated Poisson model with relative reporting rate parametrization

Usage

lrt_zi_poisson(contin_table, nsim = 10000, ...)

Value

Returns a pvlrt object. See pvlrt for more details.

Arguments

contin_table

IxJ contingency table showing pairwise counts of adverse events for I AE (along the rows) and J Drugs (along the columns)

nsim

Number of simulated null contingency table to use for computing the p-value of the test

...

additional arguments passed to pvlrt

See Also

pvlrt

Examples

Run this code

data("statin46")

# 500 bootstrap iterations (nsim) in the example below
# are for quick demonstration only --
# we recommended setting nsim to 10000 (default) or bigger
test1 <- lrt_zi_poisson(statin46, nsim = 500)
test1

Run the code above in your browser using DataLab